#!/bin/bash
PRODUCTNAME="radmin"
TMPDIR="/tmp/radmin"
INSTALLDIR="/usr/local"
IPCDIR="/etc/ipconnect"
OLDVERSION=-1
NEWVERSION=-1
MAJORVERSION=1

mkdir -p "$TMPDIR"
mkdir -p "$IPCDIR"

if [ -e "$IPCDIR/$PRODUCTNAME.ver" ]
then
  OLDVERSION=$(cat "$IPCDIR/$PRODUCTNAME.ver" |cut -d"." -f2)
else
#we will start the service as it's a fresh install. if not, we don't start it
cat > /etc/radmin/config.json <<-"EOF"
{
	"enabled": true,
	"server": "",
	"webPort": 80,
	"sshPort": 22,
	"serial": "",
	"uploadLimitRate": 0,
	"backupDay": 7,
	"backupTime": "02:30"
}
EOF
fi
NEWVERSION=$(head -n 1 "$INSTALLDIR/$PRODUCTNAME/version.txt" |cut -d"." -f2)
echo "-- Updating from $MAJORVERSION.$OLDVERSION to $MAJORVERSION.$NEWVERSION"

#On va faire une boucle à partir de "ancienne version + 1" jusqu'a la derniere version incluse
i=$(($OLDVERSION+1))
if [ $OLDVERSION -eq $NEWVERSION ]
then
	i=$OLDVERSION;
	echo "-- Updating same version but different revision, reexecuting patch of $i"
fi

while [ $i -le $NEWVERSION ]
do
  if [ -f "$INSTALLDIR/$PRODUCTNAME/InstallScripts/$MAJORVERSION.$i/update.sh" ]
  then
    echo "-- Executing patch $MAJORVERSION.$i"
    find "$INSTALLDIR/$PRODUCTNAME/InstallScripts/$MAJORVERSION.$i" -name '*' -exec dos2unix {} 2> /dev/null \;
    bash "$INSTALLDIR/$PRODUCTNAME/InstallScripts/$MAJORVERSION.$i/update.sh"
  fi
    i=$(($i+1))
done

dos2unix $INSTALLDIR/$PRODUCTNAME/scripts/*
chmod +x $INSTALLDIR/$PRODUCTNAME/scripts/*

echo "$MAJORVERSION.$NEWVERSION" > "$IPCDIR/$PRODUCTNAME.ver"
echo "-- Update finished"

rm -rf "$TMPDIR"

ENABLED=`cat /etc/radmin/config.json | jq .enabled`
systemctl daemon-reload >/dev/null
if [ "$ENABLED" = "true" ]
then
  systemctl enable radmin >/dev/null 
  systemctl restart radmin >/dev/null
fi

exit