#!/bin/bash

function showUsage {
  echo "Usage: $(basename $0) [command]"
  echo "Run a specific command."
  echo "  restart              Restart radmin service (does not enable it)"
  echo "  enable               Enable radmin service (does not start it)"
  echo "  disable              Disable radmin service (does not stop it)"
  echo "  stop                 Stop radmin service (does not disable it)"
  echo "  status               Return connection status to server (exit with 0 if connected, 1 otherwise)"
  echo "  reboot               Reboot the PBX"
  echo "  restart_asterisk     Restart asterisk process"
  echo "  reload_sip           Reload asterisk sip config"
  echo "  hangup_all           Hangup all channels on asterisk"
  echo "  sip_show_peers       Show sip peers state"
  echo "  sip_show_registry    Show sip registration state"
  echo "  sip_show_channels    Show sip channels"
  echo "  core_show_channels   Show all technologies channels"
  echo "  pri_show_spans       Show bri/pri channels state"
  echo "  send_backup          Force backup and send it to radmin (must have the feature enabled)"
  echo "  get_licenses         Return licenses information using json"
  echo "  update               Perform a CPBX update, securely"
  exit 1
}

if [ $# -lt 1 ]
then
  showUsage
  exit 1
fi


COMMAND=$1
SRV=`cat /etc/radmin/config.json | jq -r .server`
PORT=`cat /etc/radmin/config.json | jq -r .sshPort`
if [ "$SRV" = "" ]
then
  SRV="radmin.ipconnect.fr"
fi

case $COMMAND in
  restart)
    (sleep 5; systemctl restart radmin)&
    exit $?
  ;;
  enable)
    systemctl enable radmin
    exit $?
  ;;
  disable)
    systemctl disable radmin
    exit $?
  ;;
  stop)
    systemctl stop radmin
    exit $?
  ;;
  reboot)
    (sleep 5; reboot)&
    exit $?
  ;;
  restart_asterisk)
    systemctl restart asterisk
    exit $?
  ;;
  reload_sip)
    asterisk -rx "sip reload"
    exit $?
  ;;
  hangup_all)
    asterisk -rx "channel request hangup all"
    exit $?
  ;;
  sip_show_peers)
    asterisk -rx "sip show peers"
    exit $?
  ;;
  sip_show_registry)
    asterisk -rx "sip show registry"
    exit $?
  ;;
  sip_show_channels)
    asterisk -rx "sip show channels"
    exit $?
  ;;
  core_show_channels)
    asterisk -rx "core show channels"
    exit $?
  ;;
  pri_show_spans)
    asterisk -rx "pri show spans"
    exit $?
  ;;
  send_backup)
    /usr/bin/php /usr/local/radmin/scripts/sendbackup.php -f
    exit $?
  ;;
  status)
    IP=`dig $SRV +short`
    CONNECTED=`ss -n | grep $IP:$PORT | grep ESTAB | wc -l`
    if [ "$CONNECTED" = "1" ]
    then
      echo "Radmin is connected to $IP:$PORT"
      exit 0
    else
      echo "Radmin is not connected"
      exit 1
    fi
  ;;
  get_licenses)
    /usr/bin/php /usr/local/radmin/scripts/xlic_helper.php
    exit $?
  ;;
  update) 
    /bin/bash /usr/local/radmin/scripts/auto_updater.sh
    exit $?
  ;;
  *)
    echo "Unknown command $COMMAND"
    echo ""
    showUsage
  ;;
esac

exit 0